"use strict";
// Copyright 2020 Google Inc. Use of this source code is governed by an
// MIT-style license that can be found in the LICENSE file or at
// https://opensource.org/licenses/MIT.
Object.defineProperty(exports, "__esModule", { value: true });
exports.withoutExtension = exports.pathToUrlString = exports.valueError = exports.hostError = exports.compilerError = exports.asImmutableList = exports.isNullOrUndefined = void 0;
const immutable_1 = require("immutable");
const p = require("path");
const url = require("url");
/** Checks for null or undefined. */
function isNullOrUndefined(object) {
    return object === null || object === undefined;
}
exports.isNullOrUndefined = isNullOrUndefined;
/** Returns `collection` as an immutable List. */
function asImmutableList(collection) {
    return immutable_1.List.isList(collection) ? collection : (0, immutable_1.List)(collection);
}
exports.asImmutableList = asImmutableList;
/** Constructs a compiler-caused Error. */
function compilerError(message) {
    return Error(`Compiler caused error: ${message}.`);
}
exports.compilerError = compilerError;
/** Constructs a host-caused Error. */
function hostError(message) {
    return Error(`Compiler reported error: ${message}.`);
}
exports.hostError = hostError;
/** Constructs an error caused by an invalid value type. */
function valueError(message, name) {
    return Error(name ? `$${name}: ${message}.` : `${message}.`);
}
exports.valueError = valueError;
/** Converts a (possibly relative) path on the local filesystem to a URL. */
function pathToUrlString(path) {
    if (p.isAbsolute(path))
        return url.pathToFileURL(path).toString();
    const components = p.sep === '\\' ? path.split(/[/\\]/) : path.split('/');
    return components.map(encodeURIComponent).join('/');
}
exports.pathToUrlString = pathToUrlString;
/** Returns `path` without an extension, if it had one. */
function withoutExtension(path) {
    const extension = p.extname(path);
    return path.substring(0, path.length - extension.length);
}
exports.withoutExtension = withoutExtension;
//# sourceMappingURL=utils.js.map