import { Value } from './value';
/** A SassScript color. */
export declare class SassColor extends Value {
    private redInternal?;
    private greenInternal?;
    private blueInternal?;
    private hueInternal?;
    private saturationInternal?;
    private lightnessInternal?;
    private readonly alphaInternal;
    private constructor();
    /**
     * Creates an RGB color.
     *
     * Throws an error if `red`, `green`, and `blue` aren't between `0` and `255`,
     * or if `alpha` isn't between `0` and `1`.
     */
    static rgb(red: number, green: number, blue: number, alpha?: number): SassColor;
    /**
     * Creates an HSL color.
     *
     * Throws an error if `saturation` or `lightness` aren't between `0` and
     * `100`, or if `alpha` isn't between `0` and `1`.
     */
    static hsl(hue: number, saturation: number, lightness: number, alpha?: number): SassColor;
    /**
     * Creates an HWB color.
     *
     * Throws an error if `whiteness` or `blackness` aren't between `0` and `100`,
     * or if `alpha` isn't between `0` and `1`.
     */
    static hwb(hue: number, whiteness: number, blackness: number, alpha?: number): SassColor;
    /** `this`'s red channel. */
    get red(): number;
    /** `this`'s blue channel. */
    get blue(): number;
    /** `this`'s green channel. */
    get green(): number;
    /** `this`'s hue value. */
    get hue(): number;
    /** `this`'s saturation value. */
    get saturation(): number;
    /** `this`'s hue value. */
    get lightness(): number;
    /** `this`'s whiteness value. */
    get whiteness(): number;
    /** `this`'s blackness value. */
    get blackness(): number;
    /** `this`'s alpha channel. */
    get alpha(): number;
    assertColor(): SassColor;
    /**
     * Returns a copy of `this` with its RGB channels changed to `red`, `green`,
     * `blue`, and/or `alpha`.
     */
    changeRgb(options: {
        red?: number;
        green?: number;
        blue?: number;
        alpha?: number;
    }): SassColor;
    /**
     * Returns a copy of `this` with its HSL values changed to `hue`,
     * `saturation`, `lightness`, and/or `alpha`.
     */
    changeHsl(options: {
        hue?: number;
        saturation?: number;
        lightness?: number;
        alpha?: number;
    }): SassColor;
    /**
     * Returns a copy of `this` with its HWB values changed to `hue`, `whiteness`,
     * `blackness`, and/or `alpha`.
     */
    changeHwb(options: {
        hue?: number;
        whiteness?: number;
        blackness?: number;
        alpha?: number;
    }): SassColor;
    /** Returns a copy of `this` with its alpha channel changed to `alpha`. */
    changeAlpha(alpha: number): SassColor;
    equals(other: Value): boolean;
    hashCode(): number;
    toString(): string;
    private rgbToHsl;
    private hslToRgb;
}
