import { List, OrderedMap } from 'immutable';
import { Value } from './value';
import { SassMap } from './map';
/** The types of separator that a SassList can have. */
export declare type ListSeparator = ',' | '/' | ' ' | null;
/** A SassScript list. */
export declare class SassList extends Value {
    private readonly contentsInternal;
    private readonly separatorInternal;
    private readonly hasBracketsInternal;
    /**
     * Returns a list that contains `contents`, with the given `separator` and
     * `brackets`.
     */
    constructor(contents: Value[] | List<Value>, options?: {
        /** @default ',' */ separator?: ListSeparator;
        /** @default false */ brackets?: boolean;
    });
    /** Returns an empty list with the given `separator` and `brackets`. */
    static empty(options?: {
        /** @default null */ separator?: ListSeparator;
        /** @default false */ brackets?: boolean;
    }): SassList;
    get asList(): List<Value>;
    /** Whether `this` has brackets. */
    get hasBrackets(): boolean;
    /** `this`'s list separator. */
    get separator(): ListSeparator;
    protected get lengthAsList(): number;
    assertList(): SassList;
    assertMap(name?: string): SassMap;
    /**
     * If `this` is empty, returns an empty OrderedMap.
     *
     * Otherwise, returns null.
     */
    tryMap(): OrderedMap<Value, Value> | null;
    equals(other: Value): boolean;
    hashCode(): number;
    toString(): string;
}
